complete_handshake

Function complete_handshake 

async fn complete_handshake(
    framed: &mut Framed<TcpStream, ObjectCodec>,
) -> Result<Version, Error>
Completes the handshake with the server and returns the version.

“Handshake” is a bit of a misnomer, as the server really just sends the version and the client receives it.